.. _github-stats-3-1-1:

GitHub Stats for Matplotlib 3.1.1
=================================

GitHub stats for 2019/05/18 - 2019/06/30 (tag: v3.1.0)

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 30 issues and merged 120 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/46?closed=1>`__

The following 30 authors contributed 323 commits.

* Adam Gomaa
* Antony Lee
* Ben Root
* Christer Jensen
* chuanzhu xu
* David Stansby
* Deng Tian
* djdt
* Dora Fraeman Caswell
* Elan Ernest
* Elliott Sales de Andrade
* Eric Firing
* Filipe Fernandes
* Ian Thomas
* ImportanceOfBeingErnest
* Jody Klymak
* Johannes H. Jensen
* Jonas Camillus Jeppesen
* LeiSurrre
* Matt Adamson
* MeeseeksMachine
* Molly Rossow
* Nathan Goldbaum
* Nelle Varoquaux
* Paul Ivanov
* RoryIAngus
* Ryan May
* Thomas A Caswell
* Thomas Robitaille
* Tim Hoffmann

GitHub issues and pull requests:

Pull Requests (120):

* :ghpull:`14636`: Don't capture stderr in _check_and_log_subprocess.
* :ghpull:`14655`: Backport PR #14649 on branch v3.1.x (Fix appveyor conda py37)
* :ghpull:`14649`: Fix appveyor conda py37
* :ghpull:`14646`: Backport PR #14640 on branch v3.1.x (FIX: allow secondary axes to be non-linear)
* :ghpull:`14640`: FIX: allow secondary axes to be non-linear
* :ghpull:`14643`: Second attempt at fixing axis inversion (for mpl3.1).
* :ghpull:`14623`: Fix axis inversion with loglocator and logitlocator.
* :ghpull:`14619`: Backport PR #14598 on branch v3.1.x (Fix inversion of shared axes.)
* :ghpull:`14621`: Backport PR #14613 on branch v3.1.x (Cleanup DateFormatter docstring.)
* :ghpull:`14622`: Backport PR #14611 on branch v3.1.x (Update some axis docstrings.)
* :ghpull:`14611`: Update some axis docstrings.
* :ghpull:`14613`: Cleanup DateFormatter docstring.
* :ghpull:`14598`: Fix inversion of shared axes.
* :ghpull:`14610`: Backport PR #14579 on branch v3.1.x (Fix inversion of 3d axis.)
* :ghpull:`14579`: Fix inversion of 3d axis.
* :ghpull:`14600`: Backport PR #14599 on branch v3.1.x (DOC: Add numpngw to third party packages.)
* :ghpull:`14574`: Backport PR #14568 on branch v3.1.x (Don't assume tk canvas have a manager attached.)
* :ghpull:`14568`: Don't assume tk canvas have a manager attached.
* :ghpull:`14571`: Backport PR #14566 on branch v3.1.x (Move setting of AA_EnableHighDpiScaling before creating QApplication.)
* :ghpull:`14566`: Move setting of AA_EnableHighDpiScaling before creating QApplication.
* :ghpull:`14541`: Backport PR #14535 on branch v3.1.x (Invalidate FT2Font cache when fork()ing.)
* :ghpull:`14535`: Invalidate FT2Font cache when fork()ing.
* :ghpull:`14522`: Backport PR #14040 on branch v3.1.x (Gracefully handle non-finite z in tricontour (issue #10167))
* :ghpull:`14434`: Backport PR #14296 on branch v3.1.x (Fix barbs to accept array of bool for ``flip_barb``)
* :ghpull:`14518`: Backport PR #14509 on branch v3.1.x (Fix too large icon spacing in Qt5 on non-HiDPI screens)
* :ghpull:`14509`: Fix too large icon spacing in Qt5 on non-HiDPI screens
* :ghpull:`14514`: Backport PR #14256 on branch v3.1.x (Improve docstring of Axes.barbs)
* :ghpull:`14256`: Improve docstring of Axes.barbs
* :ghpull:`14505`: Backport PR #14395 on branch v3.1.x (MAINT: work around non-zero exit status of "pdftops -v" command.)
* :ghpull:`14504`: Backport PR #14445 on branch v3.1.x (FIX: fastpath clipped artists)
* :ghpull:`14502`: Backport PR #14451 on branch v3.1.x (FIX: return points rather than path to fix regression)
* :ghpull:`14445`: FIX: fastpath clipped artists
* :ghpull:`14497`: Backport PR #14491 on branch v3.1.x (Fix uses of PyObject_IsTrue.)
* :ghpull:`14491`: Fix uses of PyObject_IsTrue.
* :ghpull:`14492`: Backport PR #14490 on branch v3.1.x (Fix links of parameter types)
* :ghpull:`14490`: Fix links of parameter types
* :ghpull:`14489`: Backport PR #14459 on branch v3.1.x (Cleanup docstring of DraggableBase.)
* :ghpull:`14459`: Cleanup docstring of DraggableBase.
* :ghpull:`14485`: Backport #14429 on v3.1.x
* :ghpull:`14486`: Backport #14403 on v3.1.
* :ghpull:`14429`: FIX: if the first elements of an array are masked keep checking
* :ghpull:`14481`: Backport PR #14475 on branch v3.1.x (change ginoput docstring to match behavior)
* :ghpull:`14482`: Backport PR #14464 on branch v3.1.x (Mention origin and extent tutorial in API docs for origin kwarg)
* :ghpull:`14464`: Mention origin and extent tutorial in API docs for origin kwarg
* :ghpull:`14468`: Backport PR #14449: Improve docs on gridspec
* :ghpull:`14475`: change ginoput docstring to match behavior
* :ghpull:`14477`: Backport PR #14461 on branch v3.1.x (Fix out of bounds read in backend_tk.)
* :ghpull:`14476`: Backport PR #14474 on branch v3.1.x (Fix default value in docstring of errorbar func)
* :ghpull:`14461`: Fix out of bounds read in backend_tk.
* :ghpull:`14474`: Fix default value in docstring of errorbar func
* :ghpull:`14473`: Backport PR #14472 on branch v3.1.x (Fix NameError in example code for setting label via method)
* :ghpull:`14472`: Fix NameError in example code for setting label via method
* :ghpull:`14449`: Improve docs on gridspec
* :ghpull:`14450`: Backport PR #14422 on branch v3.1.x (Fix ReST note in span selector example)
* :ghpull:`14446`: Backport PR #14438 on branch v3.1.x (Issue #14372 - Add degrees to documentation)
* :ghpull:`14438`: Issue #14372 - Add degrees to documentation
* :ghpull:`14437`: Backport PR #14387 on branch v3.1.x (Fix clearing rubberband on nbagg)
* :ghpull:`14387`: Fix clearing rubberband on nbagg
* :ghpull:`14435`: Backport PR #14425 on branch v3.1.x (Lic restore license paint)
* :ghpull:`14296`: Fix barbs to accept array of bool for ``flip_barb``
* :ghpull:`14430`: Backport PR #14397 on branch v3.1.x (Correctly set clip_path on pcolorfast return artist.)
* :ghpull:`14397`: Correctly set clip_path on pcolorfast return artist.
* :ghpull:`14409`: Backport PR #14335 on branch v3.1.x (Add explanation of animation.embed_limit to matplotlibrc.template)
* :ghpull:`14335`: Add explanation of animation.embed_limit to matplotlibrc.template
* :ghpull:`14403`: Revert "Preserve whitespace in svg output."
* :ghpull:`14407`: Backport PR #14406 on branch v3.1.x (Remove extra \iint in math_symbol_table for document)
* :ghpull:`14398`: Backport PR #14394 on branch v3.1.x (Update link to "MathML torture test".)
* :ghpull:`14394`: Update link to "MathML torture test".
* :ghpull:`14389`: Backport PR #14388 on branch v3.1.x (Fixed one little spelling error)
* :ghpull:`14385`: Backport PR #14316 on branch v3.1.x (Improve error message for kiwisolver import error (DLL load failed))
* :ghpull:`14388`: Fixed one little spelling error
* :ghpull:`14384`: Backport PR #14369 on branch v3.1.x (Don't use deprecated mathcircled in docs.)
* :ghpull:`14316`: Improve error message for kiwisolver import error (DLL load failed)
* :ghpull:`14369`: Don't use deprecated mathcircled in docs.
* :ghpull:`14375`: Backport PR #14374 on branch v3.1.x (Check that the figure patch is in bbox_artists before trying to remove.)
* :ghpull:`14374`: Check that the figure patch is in bbox_artists before trying to remove.
* :ghpull:`14040`: Gracefully handle non-finite z in tricontour (issue #10167)
* :ghpull:`14342`: Backport PR #14326 on branch v3.1.x (Correctly apply PNG palette when building ImageBase through Pillow.)
* :ghpull:`14326`: Correctly apply PNG palette when building ImageBase through Pillow.
* :ghpull:`14341`: Backport PR #14337 on branch v3.1.x (Docstring cleanup)
* :ghpull:`14337`: Docstring cleanup
* :ghpull:`14325`: Backport PR #14126 on branch v3.1.x (Simplify grouped bar chart example)
* :ghpull:`14324`: Backport PR #14139 on branch v3.1.x (TST: be more explicit about identifying qt4/qt5 imports)
* :ghpull:`14126`: Simplify grouped bar chart example
* :ghpull:`14323`: Backport PR #14290 on branch v3.1.x (Convert SymmetricalLogScale to numpydoc)
* :ghpull:`14139`: TST: be more explicit about identifying qt4/qt5 imports
* :ghpull:`14290`: Convert SymmetricalLogScale to numpydoc
* :ghpull:`14321`: Backport PR #14313 on branch v3.1.x
* :ghpull:`14313`: Support masked array inputs for to_rgba and to_rgba_array.
* :ghpull:`14320`: Backport PR #14319 on branch v3.1.x (Don't set missing history buttons.)
* :ghpull:`14319`: Don't set missing history buttons.
* :ghpull:`14317`: Backport PR #14295: Fix bug in SymmetricalLogTransform.
* :ghpull:`14302`: Backport PR #14255 on branch v3.1.x (Improve docsstring of Axes.streamplot)
* :ghpull:`14255`: Improve docsstring of Axes.streamplot
* :ghpull:`14295`: Fix bug in SymmetricalLogTransform.
* :ghpull:`14294`: Backport PR #14282 on branch v3.1.x (Fix toolmanager's destroy subplots in tk)
* :ghpull:`14282`: Fix toolmanager's destroy subplots in tk
* :ghpull:`14292`: Backport PR #14289 on branch v3.1.x (BUG: Fix performance regression when plotting values from Numpy array sub-classes)
* :ghpull:`14289`: BUG: Fix performance regression when plotting values from Numpy array sub-classes
* :ghpull:`14287`: Backport PR #14286 on branch v3.1.x (fix minor typo)
* :ghpull:`14284`: Backport PR #14279 on branch v3.1.x (In case fallback to Agg fails, let the exception propagate out.)
* :ghpull:`14254`: Merge up 30x
* :ghpull:`14279`: In case fallback to Agg fails, let the exception propagate out.
* :ghpull:`14268`: Backport PR #14261 on branch v3.1.x (Updated polar documentation)
* :ghpull:`14261`: Updated polar documentation
* :ghpull:`14264`: Backport PR #14260 on branch v3.1.x (Remove old OSX FAQ page)
* :ghpull:`14260`: Remove old OSX FAQ page
* :ghpull:`14249`: Backport PR #14243 on branch v3.1.x (Update docstring of makeMappingArray)
* :ghpull:`14250`: Backport PR #14149 on branch v3.1.x
* :ghpull:`14252`: Backport PR #14248 on branch v3.1.x (Fix TextBox not respecting eventson)
* :ghpull:`14253`: Backport PR #13596 on branch v3.1.x (Normalize properties passed to bxp().)
* :ghpull:`14251`: Backport PR #14241 on branch v3.1.x (Fix linear segmented colormap with one element)
* :ghpull:`13596`: Normalize properties passed to bxp().
* :ghpull:`14248`: Fix TextBox not respecting eventson
* :ghpull:`14241`: Fix linear segmented colormap with one element
* :ghpull:`14243`: Update docstring of makeMappingArray
* :ghpull:`14238`: Backport PR #14164 on branch v3.1.x (Fix regexp for dvipng version detection)
* :ghpull:`14149`: Avoid using ``axis([xlo, xhi, ylo, yhi])`` in examples.
* :ghpull:`14164`: Fix regexp for dvipng version detection
* :ghpull:`13739`: Fix pressing tab breaks keymap in CanvasTk

Issues (30):

* :ghissue:`14620`: Plotting on a log/logit scale overwrites axis inverting
* :ghissue:`14615`: Inverting an axis using its limits does not work for log scale
* :ghissue:`14577`: Calling invert_yaxis() on a 3D plot has either no effect or removes ticks
* :ghissue:`14602`: NavigationToolbar2Tk save_figure function bug
* :ghissue:`1219`: Show fails on figures created with the object-oriented system
* :ghissue:`10167`: Segmentation fault with tricontour
* :ghissue:`13723`: RuntimeError when saving PDFs via parallel processes (not threads!)
* :ghissue:`14315`: Improvement: Better error message if kiwisolver fails to import
* :ghissue:`14356`: matplotlib.units.ConversionError on scatter of dates with a NaN in the first position
* :ghissue:`14467`: Docs for plt.ginput() have the wrong default value for show_clicks keyword argument.
* :ghissue:`14225`: Matplotlib crashes on windows while maximizing plot window when using Multicursor
* :ghissue:`14458`: DOC: small inconsistency in errobar docstring
* :ghissue:`14372`: Document that view_init() arguments should be in degrees
* :ghissue:`12201`: issues clearing rubberband on nbagg at non-default browser zoom
* :ghissue:`13576`: pcolorfast misbehaves when changing axis limits
* :ghissue:`14303`: Unable to import matplotlib on Windows 10 v1903
* :ghissue:`14283`: RendererSVG CSS 'white-space' property conflicts with default HTML CSS
* :ghissue:`14293`: imshow() producing "inverted" colors since 3.0.3
* :ghissue:`14322`: Cannot import matplotlib with Python 3.7.x on Win10Pro
* :ghissue:`14137`: Qt5 test auto-skip is not working correctly
* :ghissue:`14301`: scatter() fails on nan-containing input when providing edgecolor
* :ghissue:`14318`: Don't try to set missing history buttons.
* :ghissue:`14265`: symlog looses some points since 3.1.0 (example given)
* :ghissue:`14274`: BUG: plotting with Numpy array subclasses is slow with Matplotlib 3.1.0 (regression)
* :ghissue:`14263`: import pyplot issue -
* :ghissue:`14227`: Update "working with Mpl on OSX" docs
* :ghissue:`13448`: boxplot doesn't normalize properties before applying them
* :ghissue:`14226`: Modify matplotlib TextBox value without triggering callback
* :ghissue:`14232`: LinearSegmentedColormap with N=1 gives confusing error message
* :ghissue:`10365`: Scatter plot with non-sequence ´c´ color should give a better Error message.
